@@ -4,7 +4,8 @@
 import board
 from adafruit_apds9960.apds9960 import APDS9960
 
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 
 apds = APDS9960(i2c)
 apds.enable_proximity = True
